==> owlapi-rio-4.5.20-sources.jar: org/semanticweb/owlapi/rio/RioAbstractParserFactory.java <==
/*
 * This file is part of the OWL API.
 * 
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * 
 * Copyright (C) 2014, Commonwealth Scientific and Industrial Research Organisation
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with this program. If
 * not, see http://www.gnu.org/licenses/.
 * 
 * 
 * Alternatively, the contents of this file may be used under the terms of the Apache License,
 * Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable
 * instead of those above.
 * 
 * Copyright 2014, Commonwealth Scientific and Industrial Research Organisation
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.semanticweb.owlapi.rio;

import org.eclipse.rdf4j.rio.RDFParser;
import org.eclipse.rdf4j.rio.RDFParserFactory;
import org.semanticweb.owlapi.utilities.Injector;

/**
 * {@link RDFParserFactory} that creates RDF statements from OWL Ontologies. It is used to access
 * OWLAPI parsers from Sesame Rio APIs.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 * @since 4.0.0
 */
public abstract class RioAbstractParserFactory implements RDFParserFactory {

    private static final Injector INJECTOR = new Injector();

    @Override
    public abstract OWLAPIRDFFormat getRDFFormat();

    @Override
    public RDFParser getParser() {
        RioOWLRDFParser rioOWLRDFParser = new RioOWLRDFParser(getRDFFormat());
        INJECTOR.inject(rioOWLRDFParser);
        return rioOWLRDFParser;
    }
}

==> owlapi-rio-5.1.3-sources.jar: org/semanticweb/owlapi/rio/RioAbstractParserFactory.java <==
/*
 * This file is part of the OWL API.
 * 
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * 
 * Copyright (C) 2014, Commonwealth Scientific and Industrial Research Organisation
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with this program. If
 * not, see http://www.gnu.org/licenses/.
 * 
 * 
 * Alternatively, the contents of this file may be used under the terms of the Apache License,
 * Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable
 * instead of those above.
 * 
 * Copyright 2014, Commonwealth Scientific and Industrial Research Organisation
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.semanticweb.owlapi.rio;

import com.google.inject.Guice;
import com.google.inject.Injector;
import org.eclipse.rdf4j.rio.RDFParser;
import org.eclipse.rdf4j.rio.RDFParserFactory;
import org.semanticweb.owlapi.OWLAPIServiceLoaderModule;

/**
 * {@link RDFParserFactory} that creates RDF statements from OWL Ontologies. It
 * is used to access OWLAPI parsers from Sesame Rio APIs.
 *
 * @author Peter Ansell p_ansell@yahoo.com
 * @since 4.0.0
 */
public abstract class RioAbstractParserFactory implements RDFParserFactory {

    private static final Injector INJECTOR = Guice
        .createInjector(new OWLAPIServiceLoaderModule());

    @Override
    public abstract OWLAPIRDFFormat getRDFFormat();

    @Override
    public RDFParser getParser() {
        RioOWLRDFParser rioOWLRDFParser = new RioOWLRDFParser(getRDFFormat());
        INJECTOR.injectMembers(rioOWLRDFParser);
        return rioOWLRDFParser;
    }
}
